proc create_swimmer { posx posy posz } {

  # Global variables:
  # previously defined

  global LJid
  global LJ
  global CATA
  global INER
  global PI
  global a_axis
  global b_axis
  global c_axis
  global na_axis
  global nb_axis
  global nc_axis
  global nz_react
  global tol
  global r_c
  global mass

  # newly defined

  global Iner_a
  global Iner_b
  global Iner_c

  # Provide the moments of rotational 
  # inertia for the ellipsoid

  set Iner_a [expr (0.2*$mass*($b_axis*$b_axis+$c_axis*$c_axis))]
  set Iner_b [expr (0.2*$mass*($a_axis*$a_axis+$c_axis*$c_axis))]
  set Iner_c [expr (0.2*$mass*($a_axis*$a_axis+$b_axis*$b_axis))]

  # Start numbering from the last particle
  # added and set id of the ellipsoid's 
  # centre of mass (as a particle)

  set LJid [setmd n_part]
  part $LJid pos $posx $posy $posz type $LJ \
       mass $mass rinertia $Iner_a $Iner_b $Iner_c

  # Next we set the virtual particles that 
  # form the surface of the ellipsoid, where
  # we try to achieve a certain distance 
  # between the surface sites, that ensures 
  # that we do not use too many surface 
  # particles

  set phi_o 0.0
  set phi_n 0.0

  while { $phi_n < $PI } {

    set dis 0.0

    while { $dis < [expr $tol*$r_c] && $phi_n < $PI } {    
      set phi_n [expr $phi_n + 0.001*$PI] 
      set dc1 [expr $nc_axis*(cos($phi_n) - cos($phi_o))]
      set dic [expr $dc1*$dc1] 
      set db1 [expr $nb_axis*(sin($phi_n) - sin($phi_o))]
      set dib [expr $db1*$db1]
      set dis [expr sqrt($dic + $dib)]
    }

    # We now have the correct phi value to
    # get the right polar-related distance
  
    set sphi [expr sin($phi_n)]
    set cphi [expr cos($phi_n)]
    set phi_o $phi_n
   
    set th_o 0.0
    set th_n 0.0

    while { $th_n < [expr 2.0*$PI] } {

      set qir 0.0

      while { $qir < [expr $tol*$r_c] && $th_n < [expr 2.0*$PI] } {    
        set th_n [expr $th_n + 0.001*$PI] 
        set da1 [expr $na_axis*(cos($th_n) - cos($th_o))]
        set dia [expr $da1*$da1] 
        set db1 [expr $nb_axis*(sin($th_n) - sin($th_o))]
        set dib [expr $db1*$db1]
        set qir [expr $sphi*sqrt($dib + $dia)]
      }

      # We now have the correct theta value to
      # get the right azimuthal-related distance
      # we start with the old value to ensure that
      # the entire ellipse has at least the
      # required minimum point distance

      set sth [expr sin($th_o)]
      set cth [expr cos($th_o)]
      set th_o $th_n 

      # The virtual site is located at

      set x_virtual [expr $posx + $na_axis*$cth*$sphi]
      set y_virtual [expr $posy + $nb_axis*$sth*$sphi]
      set z_virtual [expr $posz + $nc_axis*$cphi]

      # Determine whether the surface
      # is a part of the catalyst or 
      # of the inert site

      if { $z_virtual >= [expr $posz + $nz_react] } {
##        set CATAid [setmd n_part]
        set INERid [setmd n_part]

        # Set a catalyst particle

##        part $CATAid pos $x_virtual $y_virtual $z_virtual \
##             type $CATA virtual 1 vs_auto_relate_to $LJid

        part $INERid pos $x_virtual $y_virtual $z_virtual \
             type $INER virtual 1 vs_auto_relate_to $LJid
      } else {
        set INERid [setmd n_part]

        # Set an inert particle

        part $INERid pos $x_virtual $y_virtual $z_virtual \
             type $INER virtual 1 vs_auto_relate_to $LJid
      }
    }
  }     

  # Finally we set the two tips

##  set CATAid [setmd n_part]
##  part $CATAid pos $posx $posy [expr $posz + $nc_axis] \
##       type $CATA virtual 1 vs_auto_relate_to $LJid

  set INERid [setmd n_part]
  part $INERid pos $posx $posy [expr $posz + $nc_axis] \
       type $INER virtual 1 vs_auto_relate_to $LJid

  set INERid [setmd n_part]
  part $INERid pos $posx $posy [expr $posz - $nc_axis] \
       type $INER virtual 1 vs_auto_relate_to $LJid
}
